@@ -28,8 +28,6 @@
 #include <sys/select.h>
 #endif
 
-#include <math.h>
-
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
@@ -160,48 +158,6 @@ cover_thumbnailer_finalize (GObject *object)
 
 
 
-static void
-cover_thumbnailer_size_prepared (GdkPixbufLoader        *loader,
-                                 gint                    source_width,
-                                 gint                    source_height,
-                                 TumblerThumbnailFlavor *flavor)
-{
-
-  gint    dest_width;
-  gint    dest_height;
-  gdouble hratio;
-  gdouble wratio;
-
-  g_return_if_fail (GDK_IS_PIXBUF_LOADER (loader));
-  g_return_if_fail (TUMBLER_IS_THUMBNAIL_FLAVOR (flavor));
-
-  /* get the destination size */
-  tumbler_thumbnail_flavor_get_size (flavor, &dest_width, &dest_height);
-
-  if (source_width <= dest_width && source_height <= dest_height)
-    {
-      /* do not scale the image */
-      dest_width = source_width;
-      dest_height = source_height;
-    }
-  else
-    {
-      /* determine which axis needs to be scaled down more */
-      wratio = (gdouble) source_width / (gdouble) dest_width;
-      hratio = (gdouble) source_height / (gdouble) dest_height;
-
-      /* adjust the other axis */
-      if (hratio > wratio)
-        dest_width = rint (source_width / hratio);
-     else
-        dest_height = rint (source_height / wratio);
-    }
-
-  gdk_pixbuf_loader_set_size (loader, MAX (dest_width, 1), MAX (dest_height, 1));
-}
-
-
-
 static size_t
 cover_thumbnailer_load_pixbuf_write (gpointer data,
                                      size_t   size,
@@ -349,7 +305,7 @@ cover_thumbnailer_load_perform (CoverThumbnailer  *cover,
 static GdkPixbuf *
 cover_thumbnailer_load_pixbuf (CoverThumbnailer        *cover,
                                const gchar             *url,
-                               TumblerThumbnailFlavor  *flavor,
+                               TumblerThumbnail        *thumbnail,
                                GCancellable            *cancellable,
                                GError                 **error)
 {
@@ -361,7 +317,7 @@ cover_thumbnailer_load_pixbuf (CoverThumbnailer        *cover,
   g_return_val_if_fail (url != NULL, NULL);
   g_return_val_if_fail (G_IS_CANCELLABLE (cancellable), NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
-  g_return_val_if_fail (TUMBLER_IS_THUMBNAIL_FLAVOR (flavor), NULL);
+  g_return_val_if_fail (TUMBLER_IS_THUMBNAIL (thumbnail), NULL);
 
   if (g_cancellable_is_cancelled (cancellable))
     return NULL;
@@ -369,7 +325,7 @@ cover_thumbnailer_load_pixbuf (CoverThumbnailer        *cover,
   /* create a pixbuf loader */
   loader = gdk_pixbuf_loader_new ();
   g_signal_connect (loader, "size-prepared",
-                    G_CALLBACK (cover_thumbnailer_size_prepared), flavor);
+                    G_CALLBACK (tumbler_util_size_prepared), thumbnail);
 
   /* download the image into a pixbuf loader */
   curl_handle = cover_thumbnailer_load_prepare (cover, url, cancellable);
@@ -659,10 +615,16 @@ cover_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   TumblerThumbnailFlavor *flavor;
   GFile                  *gfile;
 
+  /* do nothing if cancelled */
+  if (g_cancellable_is_cancelled (cancellable))
+    return;
+
   /* source file */
   uri = tumbler_file_info_get_uri (info);
   gfile = g_file_new_for_uri (uri);
 
+  g_debug ("Handling URI '%s'", uri);
+
   /* target data */
   thumbnail = tumbler_file_info_get_thumbnail (info);
   flavor = tumbler_thumbnail_get_flavor (thumbnail);
@@ -679,7 +641,7 @@ cover_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       if (poster_url != NULL)
         {
           /* download poster and load it in a pixbuf */
-          pixbuf = cover_thumbnailer_load_pixbuf (cover, poster_url, flavor, cancellable, &error);
+          pixbuf = cover_thumbnailer_load_pixbuf (cover, poster_url, thumbnail, cancellable, &error);
           g_free (poster_url);
         }
     }
@@ -711,7 +673,7 @@ cover_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (error != NULL)
     {
       g_signal_emit_by_name (thumbnailer, "error", uri,
-                             error->code, error->message);
+                             error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
