@@ -160,13 +160,8 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (tumbler_util_guess_is_sparse (info))
   {
     g_debug ("Video file '%s' is probably sparse, skipping", uri);
-
-    /* there was an error, emit error signal */
-    g_set_error (&error, TUMBLER_ERROR, TUMBLER_ERROR_NO_CONTENT,
-                 TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
-    g_signal_emit_by_name (thumbnailer, "error", uri,
-                           error->domain, error->code, error->message);
-    g_error_free (error);
+    g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+                           TUMBLER_ERROR_NO_CONTENT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
     return;
   }
@@ -194,11 +189,8 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (path == NULL)
     {
       /* there was an error, emit error signal */
-      g_set_error (&error, TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT,
-                   TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
-      g_signal_emit_by_name (thumbnailer, "error", uri,
-                             error->domain, error->code, error->message);
-                             g_error_free (error);
+      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+                             TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
       g_object_unref (thumbnail);
@@ -213,11 +205,8 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (res != 0)
     {
       /* there was an error, emit error signal */
-      g_set_error (&error, TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT,
-                   TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
-      g_signal_emit_by_name (thumbnailer, "error", uri,
-                             error->domain, error->code, error->message);
-      g_error_free (error);
+      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+                             TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
       g_free (path);
@@ -233,11 +222,8 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (v_stream == NULL)
     {
       /* there was an error, emit error signal */
-      g_set_error (&error, TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT,
-                   TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
-      g_signal_emit_by_name (thumbnailer, "error", uri,
-                             error->domain, error->code, error->message);
-      g_error_free (error);
+      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+                             TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
       g_object_unref (thumbnail);
