@@ -55,8 +55,8 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (FontThumbnailerProvider,
                                 font_thumbnailer_provider,
                                 G_TYPE_OBJECT,
                                 0,
-                                TUMBLER_ADD_INTERFACE (TUMBLER_TYPE_THUMBNAILER_PROVIDER,
-                                                       font_thumbnailer_provider_thumbnailer_provider_init));
+                                G_IMPLEMENT_INTERFACE_DYNAMIC (TUMBLER_TYPE_THUMBNAILER_PROVIDER,
+                                                               font_thumbnailer_provider_thumbnailer_provider_init));
 
 
 
@@ -123,6 +123,10 @@ font_thumbnailer_provider_get_thumbnailers (TumblerThumbnailerProvider *provider
   /* add the thumbnailer to the list */
   thumbnailers = g_list_append (thumbnailers, thumbnailer);
 
+  tumbler_util_dump_strv (G_LOG_DOMAIN, "Supported URI schemes",
+                          (const gchar *const *) uri_schemes);
+  tumbler_util_dump_strv (G_LOG_DOMAIN, "Supported mime types", mime_types);
+
   /* free URI schemes */
   g_strfreev (uri_schemes);
 
