@@ -54,13 +54,11 @@ tumbler_plugin_initialize (TumblerProviderPlugin *plugin)
                                     TUMBLER_MICRO_VERSION);
   if (G_UNLIKELY (mismatch != NULL))
     {
-      g_warning (_("Version mismatch: %s"), mismatch);
+      g_warning (TUMBLER_WARNING_VERSION_MISMATCH, mismatch);
       return;
     }
 
-#ifdef DEBUG
-  g_print ("Initializing the Tumbler JPEG Thumbnailer plugin\n");
-#endif
+  g_debug ("Initializing the Tumbler JPEG Thumbnailer plugin");
 
   /* register the types provided by this plugin */
   jpeg_thumbnailer_register (plugin);
@@ -75,9 +73,7 @@ tumbler_plugin_initialize (TumblerProviderPlugin *plugin)
 void
 tumbler_plugin_shutdown (void)
 {
-#ifdef DEBUG
-  g_print ("Shutting down the Tumbler JPEG Thumbnailer plugin\n");
-#endif
+  g_debug ("Shutting down the Tumbler JPEG Thumbnailer plugin");
 }
 
 
