@@ -58,8 +58,6 @@
 #include <unistd.h>
 #endif
 
-#include <math.h>
-
 #include <jpeglib.h>
 
 #include <glib.h>
@@ -75,6 +73,8 @@
 
 
 static void fatal_error_handler     (j_common_ptr                cinfo) G_GNUC_NORETURN;
+static void tvtj_free               (guchar                     *pixels,
+                                     gpointer                    data);
 static void jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
                                      GCancellable               *cancellable,
                                      TumblerFileInfo            *info);
@@ -156,6 +156,15 @@ fatal_error_handler (j_common_ptr cinfo)
 
 
 
+static void
+tvtj_free (guchar   *pixels,
+           gpointer  data)
+{
+  g_free (pixels);
+}
+
+
+
 static gboolean
 tvtj_fill_input_buffer (j_decompress_ptr cinfo)
 {
@@ -313,6 +322,7 @@ tvtj_jpeg_load (const JOCTET *content,
   if (G_LIKELY (cinfo.num_components != 1))
     {
       pixels = g_malloc (cinfo.output_width * cinfo.output_height * cinfo.num_components);
+      buffer = NULL;
       out_num_components = cinfo.num_components;
       lines[0] = pixels;
     }
@@ -330,7 +340,7 @@ tvtj_jpeg_load (const JOCTET *content,
       jpeg_read_scanlines (&cinfo, lines, 1);
 
       /* convert the data to RGB */
-      if (cinfo.num_components == 1)
+      if (cinfo.num_components == 1 && buffer != NULL)
         {
           for (n = 0; n < cinfo.output_width; ++n)
             {
@@ -361,7 +371,7 @@ tvtj_jpeg_load (const JOCTET *content,
                                    (cinfo.out_color_components == 4), 8,
                                    cinfo.output_width, cinfo.output_height,
                                    cinfo.output_width * out_num_components,
-                                   (GdkPixbufDestroyNotify) g_free, NULL);
+                                   tvtj_free, NULL);
 
 error:
   jpeg_destroy_decompress (&cinfo);
@@ -673,7 +683,7 @@ tvtj_exif_extract_thumbnail (const guchar *data,
               thumb = gdk_pixbuf_new_from_data (g_memdup (data + exif.thumb_tiff.offset, exif.thumb_tiff.length),
                                                 GDK_COLORSPACE_RGB, FALSE, 8, exif.thumb_tiff.width,
                                                 exif.thumb_tiff.height, exif.thumb_tiff.width,
-                                                (GdkPixbufDestroyNotify) g_free, NULL);
+                                                tvtj_free, NULL);
             }
         }
 
@@ -697,9 +707,11 @@ tvtj_exif_extract_thumbnail (const guchar *data,
 static GdkPixbuf*
 tvtj_jpeg_load_thumbnail (const JOCTET *content,
                           gsize         length,
-                          gint          size,
+                          gint          width,
+                          gint          height,
                           guint        *exif_orientation)
 {
+  GdkPixbuf *pixbuf = NULL;
   guint marker_len;
   guint marker;
   gsize n;
@@ -739,7 +751,13 @@ tvtj_jpeg_load_thumbnail (const JOCTET *content,
           if (marker == 0xe1 && n + marker_len <= length)
             {
               /* try to extract the Exif thumbnail */
-              return tvtj_exif_extract_thumbnail (content + n + 2, marker_len - 2, size, exif_orientation);
+              pixbuf = tvtj_exif_extract_thumbnail (content + n + 2, marker_len - 2,
+                                                    MIN (width, height), exif_orientation);
+
+              /* do not use low quality embedded thumbnail */
+              if (pixbuf != NULL && gdk_pixbuf_get_width (pixbuf) < width
+                  && gdk_pixbuf_get_height (pixbuf) < height)
+                g_clear_object (&pixbuf);
             }
 
           /* try next one then */
@@ -747,43 +765,7 @@ tvtj_jpeg_load_thumbnail (const JOCTET *content,
         }
     }
 
-  return NULL;
-}
-
-
-
-static GdkPixbuf*
-scale_pixbuf (GdkPixbuf *source,
-              gint       dest_width,
-              gint       dest_height)
-{
-  gdouble wratio;
-  gdouble hratio;
-  gint    source_width;
-  gint    source_height;
-
-  /* determine source pixbuf dimensions */
-  source_width  = gdk_pixbuf_get_width  (source);
-  source_height = gdk_pixbuf_get_height (source);
-
-  /* don't do anything if there is no need to resize */
-  if (source_width <= dest_width && source_height <= dest_height)
-    return g_object_ref (source);
-
-  /* determine which axis needs to be scaled down more */
-  wratio = (gdouble) source_width  / (gdouble) dest_width;
-  hratio = (gdouble) source_height / (gdouble) dest_height;
-
-  /* adjust the other axis */
-  if (hratio > wratio)
-    dest_width = rint (source_width / hratio);
-  else
-    dest_height = rint (source_height / wratio);
-
-  /* scale the pixbuf down to the desired size */
-  return gdk_pixbuf_scale_simple (source, MAX (dest_width, 1),
-                                  MAX (dest_height, 1),
-                                  GDK_INTERP_BILINEAR);
+  return pixbuf;
 }
 
 
@@ -804,7 +786,6 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   JOCTET                 *content;
   GError                 *error = NULL;
   GFile                  *file;
-  gchar                  *path;
   gsize                   length;
   gint                    fd;
   gint                    height;
@@ -820,6 +801,7 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
     return;
 
   uri = tumbler_file_info_get_uri (info);
+  g_debug ("Handling URI '%s'", uri);
 
   /* try to open the source file for reading */
   file = g_file_new_for_uri (uri);
@@ -836,10 +818,8 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 #ifdef HAVE_MMAP
   if (g_file_is_native (file))
     {
-      path = g_file_get_path (file);
-
       /* try to open the file at the given path */
-      fd = open (path, O_RDONLY);
+      fd = open (g_file_peek_path (file), O_RDONLY);
       if (G_LIKELY (fd >= 0))
         {
           /* determine the status of the file */
@@ -855,7 +835,8 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
                   guint exif_orientation = 0;
 
                   /* try to load the embedded thumbnail first */
-                  pixbuf = tvtj_jpeg_load_thumbnail (content, statb.st_size, size, &exif_orientation);
+                  pixbuf = tvtj_jpeg_load_thumbnail (content, statb.st_size, width, height,
+                                                     &exif_orientation);
                   if (pixbuf == NULL)
                     {
                       /* fall back to loading and scaling the image itself */
@@ -863,9 +844,8 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
                       if (G_UNLIKELY(pixbuf == NULL))
                         {
-                          g_set_error (&error, TUMBLER_ERROR, 
-                                       TUMBLER_ERROR_INVALID_FORMAT,
-                                       _("Thumbnail could not be inferred from file contents"));
+                          g_set_error (&error, TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT,
+                                       TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
                         }
                       else if (exif_orientation > 1)
                         {
@@ -890,8 +870,6 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
           /* close the file */
           close (fd);
         }
-
-      g_free (path);
     }
 #endif
 
@@ -903,7 +881,7 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       if (error == NULL)
         {
           guint exif_orientation = 0;
-          pixbuf = tvtj_jpeg_load_thumbnail (content, length, size, &exif_orientation);
+          pixbuf = tvtj_jpeg_load_thumbnail (content, length, width, height, &exif_orientation);
 
           if (pixbuf == NULL)
             {
@@ -911,7 +889,7 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
               if (G_UNLIKELY(pixbuf == NULL))
                 {
                   g_set_error (&error, TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT,
-                               _("Thumbnail could not be inferred from file contents"));
+                               TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
                 }
               else if (exif_orientation > 1)
                 {
@@ -929,7 +907,7 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (pixbuf != NULL)
     {
-      scaled = scale_pixbuf (pixbuf, width, height);
+      scaled = tumbler_util_scale_pixbuf (pixbuf, width, height);
       g_object_unref (pixbuf);
       pixbuf = scaled;
 
@@ -950,7 +928,8 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (error != NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", uri, error->code, error->message);
+      g_signal_emit_by_name (thumbnailer, "error", uri,
+                             error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
