@@ -55,8 +55,8 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (PixbufThumbnailerProvider,
                                 pixbuf_thumbnailer_provider,
                                 G_TYPE_OBJECT,
                                 0,
-                                TUMBLER_ADD_INTERFACE (TUMBLER_TYPE_THUMBNAILER_PROVIDER,
-                                                       pixbuf_thumbnailer_provider_thumbnailer_provider_init));
+                                G_IMPLEMENT_INTERFACE_DYNAMIC (TUMBLER_TYPE_THUMBNAILER_PROVIDER,
+                                                               pixbuf_thumbnailer_provider_thumbnailer_provider_init));
 
 
 
@@ -162,6 +162,11 @@ pixbuf_thumbnailer_provider_get_thumbnailers (TumblerThumbnailerProvider *provid
                               "uri-schemes", uri_schemes, "mime-types", mime_types, 
                               NULL);
 
+  tumbler_util_dump_strv (G_LOG_DOMAIN, "Supported URI schemes",
+                          (const gchar *const *) uri_schemes);
+  tumbler_util_dump_strv (G_LOG_DOMAIN, "Supported mime types",
+                          (const gchar *const *) mime_types);
+
   /* free URI schemes and MIME types */
   g_strfreev (uri_schemes);
   g_strfreev (mime_types);
