@@ -22,9 +22,8 @@
 #include <config.h>
 #endif
 
-#include <tumbler/tumbler-marshal.h>
-#include <tumbler/tumbler-file-info.h>
 #include <tumbler/tumbler-thumbnailer.h>
+#include <tumbler/tumbler.h>
 
 
 
@@ -37,44 +36,16 @@ enum
   LAST_SIGNAL,
 };
 
-
-
-static void  tumbler_thumbnailer_class_init (TumblerThumbnailerIface *klass);
-
-
-
 static guint tumbler_thumbnailer_signals[LAST_SIGNAL];
 
 
 
-GType
-tumbler_thumbnailer_get_type (void)
-{
-  static volatile gsize g_define_type_id__volatile = 0;
-
-  if (g_once_init_enter (&g_define_type_id__volatile))
-    {
-      GType g_define_type_id =
-        g_type_register_static_simple (G_TYPE_INTERFACE,
-                                       "TumblerThumbnailer",
-                                       sizeof (TumblerThumbnailerIface),
-                                       (GClassInitFunc) tumbler_thumbnailer_class_init,
-                                       0,
-                                       NULL,
-                                       0);
-
-      g_type_interface_add_prerequisite (g_define_type_id, G_TYPE_OBJECT);
-
-      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
-    }
-
-  return g_define_type_id__volatile;
-}
+G_DEFINE_INTERFACE (TumblerThumbnailer, tumbler_thumbnailer, G_TYPE_OBJECT)
 
 
 
 static void
-tumbler_thumbnailer_class_init (TumblerThumbnailerIface *klass)
+tumbler_thumbnailer_default_init (TumblerThumbnailerIface *klass)
 {
   g_object_interface_install_property (klass,
                                        g_param_spec_pointer ("mime-types",
@@ -142,10 +113,11 @@ tumbler_thumbnailer_class_init (TumblerThumbnailerIface *klass)
                   G_STRUCT_OFFSET (TumblerThumbnailerIface, error),
                   NULL,
                   NULL,
-                  tumbler_marshal_VOID__STRING_INT_STRING,
+                  tumbler_marshal_VOID__STRING_UINT_INT_STRING,
                   G_TYPE_NONE,
-                  3,
+                  4,
                   G_TYPE_STRING,
+                  G_TYPE_UINT,
                   G_TYPE_INT,
                   G_TYPE_STRING);
 
@@ -278,8 +250,7 @@ tumbler_thumbnailer_supports_location (TumblerThumbnailer *thumbnailer,
     if (g_file_has_prefix (file, G_FILE (lp->data)))
       supported = TRUE;
 
-  g_slist_foreach (locations, (GFunc) g_object_unref, NULL);
-  g_slist_free (locations);
+  g_slist_free_full (locations, g_object_unref);
 
   return supported;
 }
@@ -310,20 +281,19 @@ tumbler_thumbnailer_supports_hash_key (TumblerThumbnailer *thumbnailer,
 
 
 
-TumblerThumbnailer **
-tumbler_thumbnailer_array_copy (TumblerThumbnailer **thumbnailers,
-                                guint                length)
+GList **
+tumbler_thumbnailer_array_copy (GList **thumbnailers,
+                                guint length)
 {
-  TumblerThumbnailer **copy;
-  guint                n;
+  GList **copy;
+  guint n;
 
   g_return_val_if_fail (thumbnailers != NULL, NULL);
 
-  copy = g_new0 (TumblerThumbnailer *, length + 1);
+  copy = g_new0 (GList *, length + 1);
 
   for (n = 0; n < length; ++n)
-    if (thumbnailers[n] != NULL)
-      copy[n] = g_object_ref (thumbnailers[n]);
+    copy[n] = g_list_copy_deep (thumbnailers[n], tumbler_util_object_ref, NULL);
 
   copy[n] = NULL;
 
@@ -333,14 +303,13 @@ tumbler_thumbnailer_array_copy (TumblerThumbnailer **thumbnailers,
 
 
 void
-tumbler_thumbnailer_array_free (TumblerThumbnailer **thumbnailers,
-                                guint                length)
+tumbler_thumbnailer_array_free (GList **thumbnailers,
+                                guint length)
 {
   guint n;
 
   for (n = 0; thumbnailers != NULL && n < length; ++n)
-    if (thumbnailers[n] != NULL)
-      g_object_unref (thumbnailers[n]);
+    g_list_free_full (thumbnailers[n], g_object_unref);
 
   g_free (thumbnailers);
 }
