@@ -38,6 +38,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include <libxfce4util/libxfce4util.h>
+
 #include <tumbler/tumbler.h>
 
 #include <tumblerd/tumbler-cache-service.h>
@@ -120,6 +122,9 @@ main (int    argc,
   G_GNUC_END_IGNORE_DEPRECATIONS
 #endif
 
+  /* initialize translations */
+  xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+
   /* set the application name. Translators: Don't translate "Tumbler". */
   g_set_application_name ("Tumbler Thumbnailing Service");
 
@@ -228,7 +233,7 @@ main (int    argc,
   
   /* Acquire the cache service dbus name */
   g_bus_own_name_on_connection (connection,
-                                "org.freedesktop.thumbnails.Cache1",
+                                TUMBLER_SERVICE_NAME_PREFIX ".Cache1",
                                 G_BUS_NAME_OWNER_FLAGS_REPLACE,
                                 NULL, /* We dont need to do anything on name acquired*/
                                 on_dbus_name_lost,
@@ -237,7 +242,7 @@ main (int    argc,
 
   /* Acquire the manager dbus name */
   g_bus_own_name_on_connection (connection,
-                                "org.freedesktop.thumbnails.Manager1",
+                                TUMBLER_SERVICE_NAME_PREFIX ".Manager1",
                                 G_BUS_NAME_OWNER_FLAGS_REPLACE,
                                 NULL, /* We dont need to do anything on name acquired*/
                                 on_dbus_name_lost,
@@ -246,7 +251,7 @@ main (int    argc,
 
   /* Acquire the thumbnailer service dbus name */
   g_bus_own_name_on_connection (connection,
-                                "org.freedesktop.thumbnails.Thumbnailer1",
+                                TUMBLER_SERVICE_NAME_PREFIX ".Thumbnailer1",
                                 G_BUS_NAME_OWNER_FLAGS_REPLACE,
                                 NULL, /* We dont need to do anything on name acquired*/
                                 on_dbus_name_lost,
